'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.accessors = void 0;
exports.accessors = {
    asArray: function (s, delimiter) {
        if (delimiter === void 0) { delimiter = ','; }
        if (!s.length) {
            return [];
        }
        else {
            return s.split(delimiter).filter(Boolean);
        }
    },
    asEnum: function (s, validValues) {
        if ((validValues).indexOf(s) < 0) {
            throw new Error("should be one of [".concat(validValues.join(', '), "]"));
        }
        return s;
    },
    asBool: function (s) {
        var val = s.toLowerCase();
        var allowedValues = [
            'false',
            '0',
            'true',
            '1'
        ];
        if (allowedValues.indexOf(val) === -1) {
            throw new Error('should be either "true", "false", "TRUE", "FALSE", 1, or 0');
        }
        return !(((val === '0') || (val === 'false')));
    },
    asBoolStrict: function (s) {
        var val = s.toLowerCase();
        if ((val !== 'false') && (val !== 'true')) {
            throw new Error('should be either "true", "false", "TRUE", or "FALSE"');
        }
        return val !== 'false';
    },
    asJson: function (s) {
        var val;
        try {
            val = JSON.parse(s);
        }
        catch (e) {
            throw new Error('should be valid parseable JSON');
        }
        if (val && (Array.isArray(val) || typeof val === 'object')) {
            // JSON.parse can be passed strings and will attempt to parse them, and
            // even parses the string "null" to the value null. Filter those out...
            return val;
        }
        else {
            throw new Error('should be a valid JSON object or array');
        }
    },
    asJsonObject: function (s) {
        var ret = exports.accessors.asJson(s);
        if (ret === undefined || Array.isArray(ret)) {
            throw new Error('should be a parseable JSON Object');
        }
        return ret;
    },
    asJsonArray: function (s) {
        var ret = exports.accessors.asJson(s);
        if (!Array.isArray(ret)) {
            throw new Error('should be a parseable JSON Array');
        }
        return ret;
    },
    asFloat: function (s) {
        var n = parseFloat(s);
        if (isNaN(n) || n.toString() !== s) {
            throw new Error('should be a valid float');
        }
        return n;
    },
    asFloatPositive: function (s) {
        var ret = exports.accessors.asFloat(s);
        if (ret < 0) {
            throw new Error('should be a positive float');
        }
        return ret;
    },
    asFloatNegative: function (s) {
        var ret = exports.accessors.asFloat(s);
        if (ret > 0) {
            throw new Error('should be a negative float');
        }
        return ret;
    },
    asInt: function (s) {
        var n = parseInt(s, 10);
        if (isNaN(n) || n.toString(10) !== s) {
            throw new Error('should be a valid integer');
        }
        return n;
    },
    asIntNegative: function (s) {
        var ret = exports.accessors.asInt(s);
        if (ret > 0) {
            throw new Error('should be a negative integer');
        }
        return ret;
    },
    asIntPositive: function (s) {
        var ret = exports.accessors.asInt(s);
        if (ret < 0) {
            throw new Error('should be a positive integer');
        }
        return ret;
    },
    asPortNumber: function (s) {
        var ret = exports.accessors.asIntPositive(s);
        if (ret > 65535) {
            throw new Error('cannot assign a port number greater than 65535');
        }
        return ret;
    },
    asUrlString: function (s) {
        return exports.accessors.asUrlObject(s).toString();
    },
    asUrlObject: function (s) {
        try {
            return new URL(s);
        }
        catch (e) {
            throw new Error('should be a valid URL');
        }
    },
    asRegExp: function (s, flags) {
        // We have to test the value and flags indivudally if we want to write our
        // own error messages,as there is no way to differentiate between the two
        // errors except by using string comparisons.
        // Test the flags
        try {
            RegExp('', flags);
        }
        catch (err) {
            throw new Error('invalid regexp flags');
        }
        try {
            return new RegExp(s, flags);
        }
        catch (err) {
            // We know that the regexp is the issue because we tested the flags earlier
            throw new Error('should be a valid regexp');
        }
    }
};
